function [filts, mtrx] = fetch_state(ifo_name, t0, filt_dir)
  % fetch filter state for use in sim_inj
  %
  % [filts, mtrx] = fetch_state(ifo_name, t0, filt_dir)
  
  % download filter files for this gps
  t0 = round(t0);
  if nargin < 3
    disp('Fetching filter files from SVN...')
    base_dir = '/tmp/filter_files';
    filt_dir = GWFilt.CDS_fetch_files(ifo_name, t0, base_dir, true);
  end
  
  % OMC front end filters
  file_name = [filt_dir '/' ifo_name 'OMC.txt'];
  filter_names = {'OMC-DCPD_SUM', 'OMC-READOUT_ERR', 'LSC-OMC_DC', 'LSC-DARM'};
  [~, filtOMC] = GWFilt.CDS_get(ifo_name, filter_names, t0, file_name);
  
  % SUS front end filters
  seg_names = {'LL', 'LR', 'UL', 'UR'};
  stage12_names = [{'LOCK_L', 'DRIVEALIGN_L2L'}, ...
    strcat('COILOUTF_', seg_names)];
  stage3_names = [{'ISCINF_L', 'LOCK_L', 'DRIVEALIGN_L2L'}, ...
    strcat('ESDOUTF_', seg_names)];
  stage_names = [strcat('L1_', stage12_names), ...
    strcat('L2_', stage12_names), strcat('L3_', stage3_names)];
  
  file_name = [filt_dir '/' ifo_name 'SUSETMX.txt'];
  etmx_names = strcat('SUS-ETMX_', stage_names);
  [~, filtETMX] = GWFilt.CDS_get(ifo_name, etmx_names, t0, file_name);
  
  file_name = [filt_dir '/' ifo_name 'SUSETMY.txt'];
  etmy_names = strcat('SUS-ETMY_', stage_names);
  [~, filtETMY] = GWFilt.CDS_get(ifo_name, etmy_names, t0, file_name);
  
  % merge filter structs
  pairs = [fieldnames(filtOMC), struct2cell(filtOMC)
    fieldnames(filtETMX), struct2cell(filtETMX)
    fieldnames(filtETMY), struct2cell(filtETMY)].';
  filts = struct(pairs{:});

  
  % get some matrix elements  
  %   INPUT_MTRX_RAMPING_1_1 is OMC_DC to DARM
  %   OUTPUT_MTRX_{1, 2}_1 is DARM to ETMX and ETMY
  darm_names = {'LSC-ARM_INPUT_MTRX_1_1', ...
    'LSC-ARM_OUTPUT_MTRX_1_1', 'LSC-ARM_OUTPUT_MTRX_2_1'};
  eul_names = {'_1_1', '_2_1', '_3_1', '_4_1'};
  sus_names = [strcat('L1_EUL2OSEM', eul_names), ...
    strcat('L2_EUL2OSEM', eul_names), strcat('L3_EUL2ESD', eul_names)];
  mtrx_names = [darm_names, strcat('SUS-ETMX_', sus_names), ...
    strcat('SUS-ETMY_', sus_names)];
  
  % get the data
  gwd = GWData;
  chans = strcat([ifo_name, ':'], mtrx_names);
  data = gwd.fetch(t0, 1, chans, 1);
  pairs = [strrep(mtrx_names, '-', '_'); num2cell(data)];
  mtrx = struct(pairs{:});
end
